// pages/login/login.js
import WxValidate from '../../utils/wxValidate'
const app = getApp()
Page({

    /**
     * 页面的初始数据
     */
    data: {
        frameStyle: { useTop: true, name: '团队审核', leftArrow: true, useBar: false },
        // 主体高度
        infoHeight: '',
        // 选项卡
        tabs: {
            active: 'a',
            list: [
                { title: '系统团队', name: 'a' },
                { title: '解散团队', name: 'b' },
                { title: '参赛团队', name: 'c' },
            ],
        },
        // 全部团队
        aList: [],
        // 解散团队
        bList: [],
        // 参赛团队
        cList: [],
        // 弹框
        dialog: { title: '信息审核', show: false, type: '1' },
        form: {},
        statusList: [{ label: '待审核', value: '0' }, { label: '审核通过', value: '1' }, { label: '审核拒绝', value: '-1' }]
    },
    initValidate() {
        const rules = { status: { required: true } }
        // 验证字段的提示信息，若不传则调用默认的信息
        const messages = { status: { required: '请选择状态', } };
        this.WxValidate = new WxValidate(rules, messages)
    },
    back: function () {
        wx.navigateBack({ url: '/pages/administration/index' })
    },
    // 选项卡
    tabsChange: function (e) {
        const that = this;
        that.setData({ 'tabs.active': e.detail.name })
    },
    // 系统团队查看详情
    toView: async function (e) {
        const that = this;
        let { id, type } = e.currentTarget.dataset;
        if (type == 'a') {
            wx.navigateTo({ url: `/pages/teamInfo/info?id=${id}` })
        } else if (type == 'c') {
            const arr = await app.$get(`/courtAdmin/api/matchteam/${id}`);
            if (arr.errcode == '0') that.setData({ form: arr.data });
            that.setData({ dialog: { title: '团队信息', show: true, type: '2' } })
        }
    },
    // 系统团队信息审核
    toCheck: async function (e) {
        const that = this;
        let { id, type } = e.currentTarget.dataset;
        let arr;
        if (type == 'a') arr = await app.$get(`/courtAdmin/api/team/${id}`);
        else if (type == 'b') arr = await app.$get(`/courtAdmin/api/dismissapply/${id}`);
        else if (type == 'c') arr = await app.$get(`/courtAdmin/api/matchteam/${id}`);
        if (arr.errcode == '0') {
            let data = { tabs_type: type, ...arr.data };
            that.setData({ form: data })
            that.setData({ dialog: { title: '信息审核', show: true, type: '1' } })
        }

    },
    // 选择状态
    statusChange: function (e) {
        const that = this;
        const { value } = e.detail;
        that.setData({ 'form.status': value })
    },
    // 提交审核
    aSubmit: async function (e) {
        const that = this;
        const data = that.data.form;
        const params = e.detail.value;
        if (!this.WxValidate.checkForm(params)) {
            const error = this.WxValidate.errorList[0];
            wx.showToast({ title: `${error.msg}`, icon: 'error', duration: 2000 })
            return false
        } else {
            let arr;
            if (data.tabs_type == 'a') arr = await app.$post(`/courtAdmin/api/team/${data.id}`, params);
            else if (data.tabs_type == 'b') {
                arr = await app.$post(`/courtAdmin/api/dismissapply/${data.id}`, params);
                if (arr.errcode == '0' && data.status == '1') arr = await app.$delete(`/courtAdmin/api/team/${data.team_id}`);
            } else if (data.tabs_type == 'c') arr = await app.$post(`/courtAdmin/api/matchteam/${data.id}`, params);
            if (arr.errcode == '0') { wx.showToast({ title: `审核信息成功`, icon: 'error', duration: 2000 }); that.toClose(); }
            else wx.showToast({ title: `${arr.errmsg}`, icon: 'error', duration: 2000 })
        }
    },
    // 关闭弹框
    toClose: function () {
        const that = this;
        that.setData({ dialog: { title: '信息审核', show: false, } })
        that.watchLogin();
    },
    /**
     * 生命周期函数--监听页面加载
     */
    onLoad: function (options) {
        //验证规则函数
        this.initValidate();
        // 计算高度
        this.searchHeight();
        // 监听用户是否登录
        this.watchLogin();
    },
    // 监听用户是否登录
    watchLogin: function () {
        const that = this;
        wx.getStorage({
            key: 'token',
            success: async res => {
                let arr;
                // 系统团队
                arr = await app.$get(`/courtAdmin/api/team`);
                if (arr.errcode == '0') that.setData({ aList: arr.data });
                // 解散团队
                arr = await app.$get(`/courtAdmin/api/dismissapply`);
                if (arr.errcode == '0') that.setData({ bList: arr.data });
                // 参赛团队
                arr = await app.$get(`/courtAdmin/api/matchteam`);
                if (arr.errcode == '0') that.setData({ cList: arr.data });
            },
            fail: res => {
                wx.redirectTo({ url: '/pages/index/index', })
            }
        })
    },
    // 计算高度
    searchHeight: function () {
        let frameStyle = this.data.frameStyle;
        let client = app.globalData.client;
        let infoHeight = client.windowHeight;
        // 是否去掉状态栏
        if (frameStyle.useTop) infoHeight = infoHeight - (client.statusBarHeight + client.getMenu.height + (client.getMenu.top - client.statusBarHeight) * 2);
        // 是否减去底部菜单
        if (frameStyle.useBar) infoHeight = infoHeight - 50;
        if (infoHeight) this.setData({ infoHeight: infoHeight })
    },

    /**
     * 生命周期函数--监听页面初次渲染完成
     */
    onReady: function () {

    },

    /**
     * 生命周期函数--监听页面显示
     */
    onShow: function () {

    },

    /**
     * 生命周期函数--监听页面隐藏
     */
    onHide: function () {

    },

    /**
     * 生命周期函数--监听页面卸载
     */
    onUnload: function () {

    },

    /**
     * 页面相关事件处理函数--监听用户下拉动作
     */
    onPullDownRefresh: function () {

    },

    /**
     * 页面上拉触底事件的处理函数
     */
    onReachBottom: function () {

    },

    /**
     * 用户点击右上角分享
     */
    onShareAppMessage: function () {

    }
})